@@ -1,5 +1,5 @@
 from rest_framework import serializers
-from rest_auth.serializers import LoginSerializer
+from dj_rest_auth.serializers import LoginSerializer
 from ..helpers import has_mfa
 
 
